@@ -96,27 +96,6 @@ parsimony <- function(tree, data, method = "fitch", cost=NULL, site = "pscore"){
 }
 
 
-prepareDataFitch <- function(data) {
-  lev <- attr(data, "levels")
-  l <- length(lev)
-  nr <- attr(data, "nr")
-  nc <- length(data)
-  contrast <- attr(data, "contrast")
-  tmp <- contrast %*% 2L^c(0L:(l - 1L))
-  tmp <- as.integer(tmp)
-  attrData <- attributes(data)
-  nam <- attrData$names
-  attrData$names <- NULL
-  data <- unlist(data, FALSE, FALSE)
-  X <- tmp[data]
-  attributes(X) <- attrData
-  attr(X, "dim") <- c(nr, nc)
-  dimnames(X) <- list(NULL, nam)
-  class(X) <- NULL
-  X
-}
-
-
 compressSites <- function(data) {
   attrData <- attributes(data)
   lev <- attr(data, "levels")
@@ -507,7 +486,8 @@ pratchet <- function(data, start = NULL, method = "fitch", maxit = 1000,
   search_trees <- vector("list", maxit)
   tree <- NULL
   mp <- Inf
-
+  # TODO use rooted trees if cost is not symmetric
+  ROOTED <- FALSE
   # remove parsimony uniformative sie or duplicates
   if(method=="fitch"){
     weight <- attr(data, "weight")
@@ -519,6 +499,19 @@ pratchet <- function(data, start = NULL, method = "fitch", maxit = 1000,
   }
   else data <- unique(data)
 
+  star_tree <- ifelse(attr(data, "nr") == 0, TRUE, FALSE)
+  add_taxa <- ifelse(is.null(attr(data, "duplicated")), FALSE, TRUE)
+  nTips <- length(data)
+  # check for trivial trees
+  if (nTips < (3L + !ROOTED)  || star_tree) {
+    nam <- names(data)
+    if (star_tree) tree <- stree(length(nam), tip.label = nam)
+    else tree <- stree(nTips, tip.label = nam)
+    if(add_taxa) tree <- addTaxa(tree, attr(data, "duplicated"))
+    if(!ROOTED) tree <- unroot(tree)
+    return(tree)
+  }
+
   if (perturbation != "random_addition"){
     if(is.null(start)) start <- optim.parsimony(fastme.ols(dist.hamming(data)),
                                        data, trace = trace-1, method = method,
